============
chibi_gob_mx
============


.. image:: https://img.shields.io/pypi/v/chibi_gob_mx.svg
        :target: https://pypi.python.org/pypi/chibi_gob_mx

.. image:: https://img.shields.io/travis/dem4ply/chibi_gob_mx.svg
        :target: https://travis-ci.org/dem4ply/chibi_gob_mx

.. image:: https://readthedocs.org/projects/chibi-gob-mx/badge/?version=latest
        :target: https://chibi-gob-mx.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




python client for use the open api of gobmx


* Free software: WTFPL
* Documentation: https://chibi-gob-mx.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
